import * as React from 'react';
import * as zod from 'zod';
import { IFrameWindow } from '@crossmint/client-sdk-window';

declare function useSignerIFrameWindow(url?: string): React.MutableRefObject<IFrameWindow<{
    readonly "response:create-signer": zod.ZodUnion<[zod.ZodObject<{
        status: zod.ZodLiteral<"error">;
        error: zod.ZodString;
        code: zod.ZodOptional<zod.ZodString>;
        data: zod.ZodOptional<zod.ZodAny>;
    }, "strip", zod.ZodTypeAny, {
        status: "error";
        error: string;
        code?: string | undefined;
        data?: any;
    }, {
        status: "error";
        error: string;
        code?: string | undefined;
        data?: any;
    }>, zod.ZodObject<{
        address: zod.ZodOptional<zod.ZodString>;
        status: zod.ZodLiteral<"success">;
    }, zod.UnknownKeysParam, zod.ZodTypeAny, {
        status: "success";
        address?: string | undefined;
    }, {
        status: "success";
        address?: string | undefined;
    }>]>;
    readonly "response:get-attestation": zod.ZodUnion<[zod.ZodObject<{
        status: zod.ZodLiteral<"error">;
        error: zod.ZodString;
        code: zod.ZodOptional<zod.ZodString>;
        data: zod.ZodOptional<zod.ZodAny>;
    }, "strip", zod.ZodTypeAny, {
        status: "error";
        error: string;
        code?: string | undefined;
        data?: any;
    }, {
        status: "error";
        error: string;
        code?: string | undefined;
        data?: any;
    }>, zod.ZodObject<{
        attestationDocument: zod.ZodRecord<zod.ZodString, zod.ZodAny>;
        status: zod.ZodLiteral<"success">;
    }, zod.UnknownKeysParam, zod.ZodTypeAny, {
        status: "success";
        attestationDocument: Record<string, any>;
    }, {
        status: "success";
        attestationDocument: Record<string, any>;
    }>]>;
    readonly "response:send-otp": zod.ZodUnion<[zod.ZodObject<{
        status: zod.ZodLiteral<"error">;
        error: zod.ZodString;
        code: zod.ZodOptional<zod.ZodString>;
        data: zod.ZodOptional<zod.ZodAny>;
    }, "strip", zod.ZodTypeAny, {
        status: "error";
        error: string;
        code?: string | undefined;
        data?: any;
    }, {
        status: "error";
        error: string;
        code?: string | undefined;
        data?: any;
    }>, zod.ZodObject<{
        address: zod.ZodString;
        status: zod.ZodLiteral<"success">;
    }, zod.UnknownKeysParam, zod.ZodTypeAny, {
        status: "success";
        address: string;
    }, {
        status: "success";
        address: string;
    }>]>;
    readonly "response:get-public-key": zod.ZodUnion<[zod.ZodObject<{
        status: zod.ZodLiteral<"error">;
        error: zod.ZodString;
        code: zod.ZodOptional<zod.ZodString>;
        data: zod.ZodOptional<zod.ZodAny>;
    }, "strip", zod.ZodTypeAny, {
        status: "error";
        error: string;
        code?: string | undefined;
        data?: any;
    }, {
        status: "error";
        error: string;
        code?: string | undefined;
        data?: any;
    }>, zod.ZodObject<{
        publicKey: zod.ZodString;
        status: zod.ZodLiteral<"success">;
    }, zod.UnknownKeysParam, zod.ZodTypeAny, {
        status: "success";
        publicKey: string;
    }, {
        status: "success";
        publicKey: string;
    }>]>;
    readonly "response:sign": zod.ZodUnion<[zod.ZodObject<{
        status: zod.ZodLiteral<"error">;
        error: zod.ZodString;
        code: zod.ZodOptional<zod.ZodString>;
        data: zod.ZodOptional<zod.ZodAny>;
    }, "strip", zod.ZodTypeAny, {
        status: "error";
        error: string;
        code?: string | undefined;
        data?: any;
    }, {
        status: "error";
        error: string;
        code?: string | undefined;
        data?: any;
    }>, zod.ZodObject<{
        publicKey: zod.ZodString;
        signature: zod.ZodString;
        status: zod.ZodLiteral<"success">;
    }, zod.UnknownKeysParam, zod.ZodTypeAny, {
        status: "success";
        publicKey: string;
        signature: string;
    }, {
        status: "success";
        publicKey: string;
        signature: string;
    }>]>;
}, {
    readonly "request:create-signer": zod.ZodObject<{
        authData: zod.ZodObject<{
            jwt: zod.ZodString;
            apiKey: zod.ZodString;
        }, "strip", zod.ZodTypeAny, {
            jwt: string;
            apiKey: string;
        }, {
            jwt: string;
            apiKey: string;
        }>;
        data: zod.ZodObject<{
            authId: zod.ZodString;
            chainLayer: zod.ZodEnum<["solana", "evm"]>;
        }, "strip", zod.ZodTypeAny, {
            authId: string;
            chainLayer: "solana" | "evm";
        }, {
            authId: string;
            chainLayer: "solana" | "evm";
        }>;
    }, "strip", zod.ZodTypeAny, {
        authData: {
            jwt: string;
            apiKey: string;
        };
        data: {
            authId: string;
            chainLayer: "solana" | "evm";
        };
    }, {
        authData: {
            jwt: string;
            apiKey: string;
        };
        data: {
            authId: string;
            chainLayer: "solana" | "evm";
        };
    }>;
    readonly "request:get-attestation": zod.ZodObject<{
        challenge: zod.ZodString;
    }, "strip", zod.ZodTypeAny, {
        challenge: string;
    }, {
        challenge: string;
    }>;
    readonly "request:send-otp": zod.ZodObject<{
        authData: zod.ZodObject<{
            jwt: zod.ZodString;
            apiKey: zod.ZodString;
        }, "strip", zod.ZodTypeAny, {
            jwt: string;
            apiKey: string;
        }, {
            jwt: string;
            apiKey: string;
        }>;
        data: zod.ZodObject<{
            encryptedOtp: zod.ZodString;
            chainLayer: zod.ZodEnum<["solana", "evm"]>;
        }, "strip", zod.ZodTypeAny, {
            chainLayer: "solana" | "evm";
            encryptedOtp: string;
        }, {
            chainLayer: "solana" | "evm";
            encryptedOtp: string;
        }>;
    }, "strip", zod.ZodTypeAny, {
        authData: {
            jwt: string;
            apiKey: string;
        };
        data: {
            chainLayer: "solana" | "evm";
            encryptedOtp: string;
        };
    }, {
        authData: {
            jwt: string;
            apiKey: string;
        };
        data: {
            chainLayer: "solana" | "evm";
            encryptedOtp: string;
        };
    }>;
    readonly "request:get-public-key": zod.ZodObject<{
        authData: zod.ZodObject<{
            jwt: zod.ZodString;
            apiKey: zod.ZodString;
        }, "strip", zod.ZodTypeAny, {
            jwt: string;
            apiKey: string;
        }, {
            jwt: string;
            apiKey: string;
        }>;
        data: zod.ZodObject<{
            chainLayer: zod.ZodEnum<["solana", "evm"]>;
        }, "strip", zod.ZodTypeAny, {
            chainLayer: "solana" | "evm";
        }, {
            chainLayer: "solana" | "evm";
        }>;
    }, "strip", zod.ZodTypeAny, {
        authData: {
            jwt: string;
            apiKey: string;
        };
        data: {
            chainLayer: "solana" | "evm";
        };
    }, {
        authData: {
            jwt: string;
            apiKey: string;
        };
        data: {
            chainLayer: "solana" | "evm";
        };
    }>;
    readonly "request:sign": zod.ZodObject<{
        authData: zod.ZodObject<{
            jwt: zod.ZodString;
            apiKey: zod.ZodString;
        }, "strip", zod.ZodTypeAny, {
            jwt: string;
            apiKey: string;
        }, {
            jwt: string;
            apiKey: string;
        }>;
        data: zod.ZodObject<{
            keyType: zod.ZodEnum<["secp256k1", "ed25519"]>;
            bytes: zod.ZodString;
            encoding: zod.ZodDefault<zod.ZodOptional<zod.ZodEnum<["base58"]>>>;
        }, "strip", zod.ZodTypeAny, {
            keyType: "secp256k1" | "ed25519";
            bytes: string;
            encoding: "base58";
        }, {
            keyType: "secp256k1" | "ed25519";
            bytes: string;
            encoding?: "base58" | undefined;
        }>;
    }, "strip", zod.ZodTypeAny, {
        authData: {
            jwt: string;
            apiKey: string;
        };
        data: {
            keyType: "secp256k1" | "ed25519";
            bytes: string;
            encoding: "base58";
        };
    }, {
        authData: {
            jwt: string;
            apiKey: string;
        };
        data: {
            keyType: "secp256k1" | "ed25519";
            bytes: string;
            encoding?: "base58" | undefined;
        };
    }>;
}> | null>;

export { useSignerIFrameWindow };
